run_script

Function run_script 

pub fn run_script(
    scripts: &Scripts,
    script_name: &str,
    env_overrides: Vec<String>,
)
Run a script by name, executing any included scripts in sequence.

This function runs a script and any scripts it includes, measuring the execution time for each script and printing performance metrics.

Arguments

  • scripts - A reference to the collection of scripts.
  • script_name - The name of the script to run.
  • env_overrides - A vector of command line environment variable overrides.

Panics

This function will panic if it fails to execute the script commands.