pub enum CargoScriptError {
Show 14 variants
ScriptFileNotFound {
path: String,
source: Error,
},
InvalidToml {
path: String,
message: String,
line: Option<usize>,
},
ScriptNotFound {
script_name: String,
available_scripts: Vec<String>,
},
ToolNotFound {
tool: String,
required_version: Option<String>,
suggestion: String,
},
ToolchainNotFound {
toolchain: String,
suggestion: String,
},
ExecutionError {
script: String,
command: String,
source: Error,
},
WindowsSelfReplacementError {
script: String,
command: String,
},
WorkspaceNotFound {
path: String,
},
ParallelExecutionFailed {
failed_scripts: Vec<String>,
},
TemplateNotFound {
name: String,
available: Vec<String>,
},
CargoScriptNotAvailable {
suggestion: String,
},
HookFailed {
hook_name: String,
script_name: String,
reason: String,
},
WatchError {
path: String,
message: String,
},
MissingScriptArgument {
script_name: String,
argument: String,
},
}Expand description
Custom error type for cargo-script operations.
Variants
ScriptFileNotFound
Script file not found or cannot be read
InvalidToml
Invalid TOML syntax in Scripts.toml
ScriptNotFound
Script not found in Scripts.toml
ToolNotFound
Required tool is missing or wrong version
ToolchainNotFound
Toolchain not installed
ExecutionError
Script execution error
WindowsSelfReplacementError
Windows self-replacement error (trying to replace cargo-script while it’s running)
WorkspaceNotFound
Workspace Cargo.toml could not be found at or above the given path
ParallelExecutionFailed
One or more scripts failed during a parallel execution
TemplateNotFound
Requested template does not exist in the registry
CargoScriptNotAvailable
cargo script (single-file packages) is not available on the current toolchain
HookFailed
A pre/post/on_success/on_failure hook failed
WatchError
Watch mode error (file system event subscription failed)
MissingScriptArgument
A required script argument/parameter was not provided