pub fn create_tool_not_found_error(
tool: &str,
required_version: Option<&str>,
) -> CargoScriptErrorExpand description
Helper function to create a tool not found error with installation suggestions.
pub fn create_tool_not_found_error(
tool: &str,
required_version: Option<&str>,
) -> CargoScriptErrorHelper function to create a tool not found error with installation suggestions.